import { RpsContext } from 'rpscript-interface';
import { ShellString, ShellArray } from 'shelljs';
/** Welcome to ShellJS Module
 * @namespace ShellJS
 *
 * @see {@link https://github.com/shelljs/shelljs}
 *
*/
export default class RpsShelljs {
    /**
     * @function cat-command
     * @memberof ShellJS
     *
     * @param {Array} filenames
     * @return {string}
     * @example
     * cat-command "filename" --options="-rf"
     *
     *
    */
    cat(ctx: RpsContext, opts: Object, ...filenames: string[]): Promise<ShellString>;
    /**
     * @function cd-command
     * @memberof ShellJS
     *
     * @param {string} directory
     * @return {void}
     * @example
     * cd-command "./dirname"
     *
     *
    */
    cd(ctx: RpsContext, opts: {}, directory: string): Promise<void>;
    /**
     * @function chmod-command
     * @memberof ShellJS
     *
     * @param {string} mode
     * @param {string} file
     * @return {void}
     * @example
     * chmod-command  "755" "filename.txt"
     *
     *
    */
    chmod(ctx: RpsContext, opts: {}, mode: string, file: string): Promise<void>;
    /**
     * @function cp-command
     * @memberof ShellJS
     *
     * @param {string} location
     * @return {void}
     * @example
     * cp-command  "file1.txt" "file2.txt" "dest/"
     *
     *
    */
    cp(ctx: RpsContext, opts: {}, ...location: string[]): Promise<void>;
    /**
     * @function echo-command
     * @memberof ShellJS
     *
     * @param {any} content
     * @return {void}
     * @example
     * echo-command  "hello world"
     * ;Print hello world in console
     *
     *
    */
    echo(ctx: RpsContext, opts: {}, content: any): Promise<any>;
    /**
   * @function find-command
   * @memberof ShellJS
   *
   * @param {string} paths
   * @return {Array}
   * @example
   * find-command  "hello world"
   *
   *
  */
    find(ctx: RpsContext, opts: {}, ...paths: string[]): Promise<ShellArray>;
    /**
     * @function grep-command
     * @memberof ShellJS
     *
     * @param {string} regexFilter
     * @param {Array} files
     * @return {string}
     * @example
     * grep-command  "hello world"
     *
     *
    */
    grep(ctx: RpsContext, opts: {}, regexFilter: string, ...files: string[]): Promise<ShellString>;
    /**
     * @function head-command
     * @memberof ShellJS
     *
     * @param {Array} file
     * @return {string}
     * @example
     * head-command  "file.txt"
     *
     *
    */
    head(ctx: RpsContext, opts: {}, ...file: string[]): Promise<ShellString>;
    /**
     * @function ln-command
     * @memberof ShellJS
     *
     * @param {string} source
     * @param {string} destination
     * @return {void}
     * @example
     * ln-command  "file.txt"
     *
     *
    */
    ln(ctx: RpsContext, opts: {}, source: string, destination: string): Promise<void>;
    /**
     * @function ls-command
     * @memberof ShellJS
     *
     * @param {string} sourcpath
     * @return {Array}
     * @example
     * ls-command  "folderA"
     *
     *
    */
    ls(ctx: RpsContext, opts: {}, ...path: string[]): Promise<ShellArray>;
    /**
     * @function mkdir-command
     * @memberof ShellJS
     *
     * @param {string} directory
     * @return {void}
     * @example
     * mkdir-command  "newFolderA"
     *
     *
    */
    mkdir(ctx: RpsContext, opts: {}, ...directory: string[]): Promise<void>;
    /**
     * @function mv-command
     * @memberof ShellJS
     *
     * @param {string} location
     * @return {void}
     * @example
     * mv-command  "locA" "locB"
     *
     *
    */
    mv(ctx: RpsContext, opts: {}, ...location: string[]): Promise<void>;
    /**
     * @function pwd-command
     * @memberof ShellJS
     *
     * @return {string}
     * @example
     * pwd-command
     *
     *
    */
    pwd(ctx: RpsContext, opts: {}): Promise<ShellString>;
    /**
     * @function rm-command
     * @memberof ShellJS
     *
     * @param {Array} file file to be removed
     * @return {string}
     * @example
     * pwd-command
     *
     *
    */
    rm(ctx: RpsContext, opts: {}, ...file: string[]): Promise<void>;
    /**
     * @function sed-command
     * @memberof ShellJS
     *
     * @param searchRegex
     * @param replacement
     * @param file
     *
     * @return {string}
     * @example
     * sed-command
     *
     *
    */
    sed(ctx: RpsContext, opts: {}, searchRegex: string, replacement: string, file: string): Promise<ShellString>;
    /**
   * @function set-command
   * @memberof ShellJS
   *
   * @param options
   * @return {void}
   *
   * @example
   * set-command
   *
   *
  */
    set(ctx: RpsContext, opts: {}, options: string): Promise<void>;
    /**
     * @function sort-command
     * @memberof ShellJS
     *
     * @param {Array} file
     * @return {string}
     *
     * @example
     * sort-command "fileA.txt" "fileB.txt"
     *
     *
    */
    sort(ctx: RpsContext, opts: {}, ...file: string[]): Promise<ShellString>;
    /**
     * @function tail-command
     * @memberof ShellJS
     *
     * @param {Array} file
     *
     * @return {string}
     * @example
     * sed-command
     *
     *
    */
    tail(ctx: RpsContext, opts: {}, ...file: string[]): Promise<ShellString>;
    /**
   * @function tempdir-command
   * @memberof ShellJS
   *
   * @return {string}
   * @example
   * tempdir-command
   *
  */
    tempdir(ctx: RpsContext, opts: {}): Promise<ShellString>;
    /**
     * @function touch-command
     * @memberof ShellJS
     *
     * @param {Array} file
     *
     * @return {void}
     * @example
     * touch-command
     *
     *
    */
    touch(ctx: RpsContext, opts: {}, ...file: string[]): Promise<void>;
    /**
     * @function uniq-command
     * @memberof ShellJS
     *
     * @param {string} input
     * @param {string} output
     *
     * @return {string}
     * @example
     * unqi-command
     *
     *
    */
    uniq(ctx: RpsContext, opts: {}, input: string, output?: string): Promise<ShellString>;
    /**
     * @function which-command
     * @memberof ShellJS
     *
     * @param command
     *
     * @return {string}
     * @example
     * which-command "node"
     *
     *
    */
    which(ctx: RpsContext, opts: {}, command: string): Promise<ShellString>;
}
