"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const rpscript_interface_1 = require("rpscript-interface");
const shelljs_1 = __importDefault(require("shelljs"));
/** Welcome to ShellJS Module
 * @namespace ShellJS
 *
 * @see {@link https://github.com/shelljs/shelljs}
 *
*/
let RpsShelljs = class RpsShelljs {
    /**
     * @function cat-command
     * @memberof ShellJS
     *
     * @param {Array} filenames
     * @return {string}
     * @example
     * cat-command "filename" --options="-rf"
     *
     *
    */
    cat(ctx, opts, ...filenames) {
        return __awaiter(this, void 0, void 0, function* () {
            let result = opts['options'] ? shelljs_1.default.cat(filenames) : shelljs_1.default.cat(opts['options'], filenames);
            return result;
        });
    }
    /**
     * @function cd-command
     * @memberof ShellJS
     *
     * @param {string} directory
     * @return {void}
     * @example
     * cd-command "./dirname"
     *
     *
    */
    cd(ctx, opts, directory) {
        return __awaiter(this, void 0, void 0, function* () {
            let result = opts['options'];
            return shelljs_1.default.cd(directory);
        });
    }
    /**
     * @function chmod-command
     * @memberof ShellJS
     *
     * @param {string} mode
     * @param {string} file
     * @return {void}
     * @example
     * chmod-command  "755" "filename.txt"
     *
     *
    */
    chmod(ctx, opts, mode, file) {
        return __awaiter(this, void 0, void 0, function* () {
            let result = opts['options'];
            if (result)
                return shelljs_1.default.chmod(result, mode, file);
            else
                return shelljs_1.default.chmod(mode, file);
        });
    }
    /**
     * @function cp-command
     * @memberof ShellJS
     *
     * @param {string} location
     * @return {void}
     * @example
     * cp-command  "file1.txt" "file2.txt" "dest/"
     *
     *
    */
    cp(ctx, opts, ...location) {
        return __awaiter(this, void 0, void 0, function* () {
            let options = opts['options'];
            let dest = location.pop();
            if (options)
                return shelljs_1.default.cp(options, location, dest);
            else
                return shelljs_1.default.cp(location, dest);
        });
    }
    /**
     * @function echo-command
     * @memberof ShellJS
     *
     * @param {any} content
     * @return {void}
     * @example
     * echo-command  "hello world"
     * ;Print hello world in console
     *
     *
    */
    echo(ctx, opts, content) {
        return __awaiter(this, void 0, void 0, function* () {
            let options = opts['options'];
            if (options)
                shelljs_1.default.echo(options, content);
            else
                shelljs_1.default.echo(content);
            return content;
        });
    }
    // @rpsAction({verbName:'exec'})
    // exec (ctx:RpsContext,opts:{}, functor:any[], fn:Function) : Promise<ExecOutputReturnValue> {
    //   shell.exec();
    // }
    /**
   * @function find-command
   * @memberof ShellJS
   *
   * @param {string} paths
   * @return {Array}
   * @example
   * find-command  "hello world"
   *
   *
  */
    find(ctx, opts, ...paths) {
        return __awaiter(this, void 0, void 0, function* () {
            return shelljs_1.default.find(paths);
        });
    }
    /**
     * @function grep-command
     * @memberof ShellJS
     *
     * @param {string} regexFilter
     * @param {Array} files
     * @return {string}
     * @example
     * grep-command  "hello world"
     *
     *
    */
    grep(ctx, opts, regexFilter, ...files) {
        return __awaiter(this, void 0, void 0, function* () {
            let options = opts['options'];
            if (options)
                return shelljs_1.default.grep(options, regexFilter, files);
            else
                return shelljs_1.default.grep(regexFilter, files);
        });
    }
    /**
     * @function head-command
     * @memberof ShellJS
     *
     * @param {Array} file
     * @return {string}
     * @example
     * head-command  "file.txt"
     *
     *
    */
    head(ctx, opts, ...file) {
        return __awaiter(this, void 0, void 0, function* () {
            let num = opts['options'];
            if (num)
                return shelljs_1.default.head({ '-n': num }, file);
            else
                return shelljs_1.default.head(file);
        });
    }
    /**
     * @function ln-command
     * @memberof ShellJS
     *
     * @param {string} source
     * @param {string} destination
     * @return {void}
     * @example
     * ln-command  "file.txt"
     *
     *
    */
    ln(ctx, opts, source, destination) {
        return __awaiter(this, void 0, void 0, function* () {
            let options = opts['options'];
            if (options)
                return shelljs_1.default.ln(options, source, destination);
            else
                return shelljs_1.default.ln(source, destination);
        });
    }
    /**
     * @function ls-command
     * @memberof ShellJS
     *
     * @param {string} sourcpath
     * @return {Array}
     * @example
     * ls-command  "folderA"
     *
     *
    */
    ls(ctx, opts, ...path) {
        return __awaiter(this, void 0, void 0, function* () {
            let options = opts['options'];
            if (options)
                return shelljs_1.default.ls(options, path);
            else
                return shelljs_1.default.ls(path);
        });
    }
    /**
     * @function mkdir-command
     * @memberof ShellJS
     *
     * @param {string} directory
     * @return {void}
     * @example
     * mkdir-command  "newFolderA"
     *
     *
    */
    mkdir(ctx, opts, ...directory) {
        return __awaiter(this, void 0, void 0, function* () {
            let options = opts['options'];
            if (options)
                return shelljs_1.default.mkdir(options, directory);
            else
                return shelljs_1.default.mkdir(directory);
        });
    }
    /**
     * @function mv-command
     * @memberof ShellJS
     *
     * @param {string} location
     * @return {void}
     * @example
     * mv-command  "locA" "locB"
     *
     *
    */
    mv(ctx, opts, ...location) {
        return __awaiter(this, void 0, void 0, function* () {
            let options = opts['options'];
            let dest = location.pop();
            if (options)
                return shelljs_1.default.mv(options, location, dest);
            else
                return shelljs_1.default.mv(location, dest);
        });
    }
    /**
     * @function pwd-command
     * @memberof ShellJS
     *
     * @return {string}
     * @example
     * pwd-command
     *
     *
    */
    pwd(ctx, opts) {
        return __awaiter(this, void 0, void 0, function* () {
            return shelljs_1.default.pwd();
        });
    }
    /**
     * @function rm-command
     * @memberof ShellJS
     *
     * @param {Array} file file to be removed
     * @return {string}
     * @example
     * pwd-command
     *
     *
    */
    rm(ctx, opts, ...file) {
        return __awaiter(this, void 0, void 0, function* () {
            let options = opts['options'];
            if (options)
                return shelljs_1.default.rm(options, file);
            else
                return shelljs_1.default.rm(file);
        });
    }
    /**
     * @function sed-command
     * @memberof ShellJS
     *
     * @param searchRegex
     * @param replacement
     * @param file
     *
     * @return {string}
     * @example
     * sed-command
     *
     *
    */
    sed(ctx, opts, searchRegex, replacement, file) {
        return __awaiter(this, void 0, void 0, function* () {
            let options = opts['options'];
            if (options)
                return shelljs_1.default.sed(options, searchRegex, replacement, file);
            else
                return shelljs_1.default.sed(searchRegex, replacement, file);
        });
    }
    /**
   * @function set-command
   * @memberof ShellJS
   *
   * @param options
   * @return {void}
   *
   * @example
   * set-command
   *
   *
  */
    set(ctx, opts, options) {
        return __awaiter(this, void 0, void 0, function* () {
            return shelljs_1.default.set(options);
        });
    }
    /**
     * @function sort-command
     * @memberof ShellJS
     *
     * @param {Array} file
     * @return {string}
     *
     * @example
     * sort-command "fileA.txt" "fileB.txt"
     *
     *
    */
    sort(ctx, opts, ...file) {
        return __awaiter(this, void 0, void 0, function* () {
            let options = opts['options'];
            if (options)
                return shelljs_1.default.sort(options, file);
            else
                return shelljs_1.default.sort(file);
        });
    }
    /**
     * @function tail-command
     * @memberof ShellJS
     *
     * @param {Array} file
     *
     * @return {string}
     * @example
     * sed-command
     *
     *
    */
    tail(ctx, opts, ...file) {
        return __awaiter(this, void 0, void 0, function* () {
            let num = opts['options'];
            if (num)
                return shelljs_1.default.tail({ '-n': num }, file);
            else
                return shelljs_1.default.tail(file);
        });
    }
    /**
   * @function tempdir-command
   * @memberof ShellJS
   *
   * @return {string}
   * @example
   * tempdir-command
   *
  */
    tempdir(ctx, opts) {
        return __awaiter(this, void 0, void 0, function* () {
            return shelljs_1.default.tempdir();
        });
    }
    /**
     * @function touch-command
     * @memberof ShellJS
     *
     * @param {Array} file
     *
     * @return {void}
     * @example
     * touch-command
     *
     *
    */
    touch(ctx, opts, ...file) {
        return __awaiter(this, void 0, void 0, function* () {
            let options = opts['options'];
            if (options)
                return shelljs_1.default.touch(options, file);
            else
                return shelljs_1.default.touch(file);
        });
    }
    /**
     * @function uniq-command
     * @memberof ShellJS
     *
     * @param {string} input
     * @param {string} output
     *
     * @return {string}
     * @example
     * unqi-command
     *
     *
    */
    uniq(ctx, opts, input, output) {
        return __awaiter(this, void 0, void 0, function* () {
            let options = opts['options'];
            if (options)
                return shelljs_1.default.uniq(options, input, output);
            else
                return shelljs_1.default.uniq(input, output);
        });
    }
    /**
     * @function which-command
     * @memberof ShellJS
     *
     * @param command
     *
     * @return {string}
     * @example
     * which-command "node"
     *
     *
    */
    which(ctx, opts, command) {
        return __awaiter(this, void 0, void 0, function* () {
            return shelljs_1.default.which(command);
        });
    }
};
__decorate([
    rpscript_interface_1.rpsAction({ verbName: 'cat-command' })
], RpsShelljs.prototype, "cat", null);
__decorate([
    rpscript_interface_1.rpsAction({ verbName: 'cd-command' })
], RpsShelljs.prototype, "cd", null);
__decorate([
    rpscript_interface_1.rpsAction({ verbName: 'chmod-command' })
], RpsShelljs.prototype, "chmod", null);
__decorate([
    rpscript_interface_1.rpsAction({ verbName: 'cp' })
], RpsShelljs.prototype, "cp", null);
__decorate([
    rpscript_interface_1.rpsAction({ verbName: 'echo-command' })
], RpsShelljs.prototype, "echo", null);
__decorate([
    rpscript_interface_1.rpsAction({ verbName: 'find-command' })
], RpsShelljs.prototype, "find", null);
__decorate([
    rpscript_interface_1.rpsAction({ verbName: 'grep-command' })
], RpsShelljs.prototype, "grep", null);
__decorate([
    rpscript_interface_1.rpsAction({ verbName: 'head-command' })
], RpsShelljs.prototype, "head", null);
__decorate([
    rpscript_interface_1.rpsAction({ verbName: 'ln-command' })
], RpsShelljs.prototype, "ln", null);
__decorate([
    rpscript_interface_1.rpsAction({ verbName: 'ls-command' })
], RpsShelljs.prototype, "ls", null);
__decorate([
    rpscript_interface_1.rpsAction({ verbName: 'mkdir-command' })
], RpsShelljs.prototype, "mkdir", null);
__decorate([
    rpscript_interface_1.rpsAction({ verbName: 'mv-command' })
], RpsShelljs.prototype, "mv", null);
__decorate([
    rpscript_interface_1.rpsAction({ verbName: 'pwd-command' })
], RpsShelljs.prototype, "pwd", null);
__decorate([
    rpscript_interface_1.rpsAction({ verbName: 'rm-command' })
], RpsShelljs.prototype, "rm", null);
__decorate([
    rpscript_interface_1.rpsAction({ verbName: 'sed-command' })
], RpsShelljs.prototype, "sed", null);
__decorate([
    rpscript_interface_1.rpsAction({ verbName: 'set-command' })
], RpsShelljs.prototype, "set", null);
__decorate([
    rpscript_interface_1.rpsAction({ verbName: 'sort-command' })
], RpsShelljs.prototype, "sort", null);
__decorate([
    rpscript_interface_1.rpsAction({ verbName: 'tail-command' })
], RpsShelljs.prototype, "tail", null);
__decorate([
    rpscript_interface_1.rpsAction({ verbName: 'tempdir' })
], RpsShelljs.prototype, "tempdir", null);
__decorate([
    rpscript_interface_1.rpsAction({ verbName: 'touch-command' })
], RpsShelljs.prototype, "touch", null);
__decorate([
    rpscript_interface_1.rpsAction({ verbName: 'uniq-command' })
], RpsShelljs.prototype, "uniq", null);
__decorate([
    rpscript_interface_1.rpsAction({ verbName: 'which-command' })
], RpsShelljs.prototype, "which", null);
RpsShelljs = __decorate([
    rpscript_interface_1.RpsModule("shelljs")
], RpsShelljs);
exports.default = RpsShelljs;
